<?php

namespace Litecms\FixedPlans\Providers;

use Illuminate\Support\ServiceProvider;

class FixedPlansServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'fixed_plans');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'fixed_plans');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.fixed_plans', function ($app) {
            return $this->app->make('Litecms\FixedPlans\FixedPlans');
        });

                // Bind FixedPlans to repository
        $this->app->bind(
            'Litecms\FixedPlans\Interfaces\FixedPlansRepositoryInterface',
            \Litecms\FixedPlans\Repositories\Eloquent\FixedPlansRepository::class
        );

        $this->app->register(\Litecms\FixedPlans\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\FixedPlans\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\FixedPlans\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.fixed_plans'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/fixed_plans.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/fixed_plans')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/fixed_plans')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
